# ingreedy-py
python port of https://github.com/iancanderson/ingreedy-js

## Installation
```bash
$ pip install ingreedypy
```

## Local Testing
```bash
$ pip install -e .[tests]
$ py.test --cov=ingreedypy ingreedytest.py
```
